pub struct VerificationMethod {
pub verification_pairs: VerificationPairs,
pub agreement_pairs: AgreementPairs,
}Expand description
VerificationMethod is an object used to generate two important keys, a verification_pairs
and an aggreement_pairs
A verification_pairs is a public and private keys used to verify a context based on some signature
An aggreement_pairs is a public and private keys used to generate the shared secret through ECDH algorithm
Fields
verification_pairs: VerificationPairsagreement_pairs: AgreementPairsTrait Implementations
Sourceimpl Clone for VerificationMethod
impl Clone for VerificationMethod
Sourcefn clone(&self) -> VerificationMethod
fn clone(&self) -> VerificationMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for VerificationMethod
impl RefUnwindSafe for VerificationMethod
impl Send for VerificationMethod
impl Sync for VerificationMethod
impl Unpin for VerificationMethod
impl UnwindSafe for VerificationMethod